package org.dromara.zhishu.service;

import org.dromara.common.mybatis.core.page.PageQuery;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.zhishu.domain.bo.TDistrictBo;
import org.dromara.zhishu.domain.vo.DistrictsVo;
import org.dromara.zhishu.domain.vo.TDistrictVo;

import java.util.Collection;
import java.util.List;

public interface ITDistrictService {

    /**
     * 查询【请填写功能名称】
     *
     * @param id 主键
     * @return 【请填写功能名称】
     */
    TDistrictVo queryById(Long id);

    /**
     * 分页查询【请填写功能名称】列表
     *
     * @param bo        查询条件
     * @param pageQuery 分页参数
     * @return 【请填写功能名称】分页列表
     */
    TableDataInfo<TDistrictVo> queryPageList(TDistrictBo bo, PageQuery pageQuery);

    /**
     * 查询符合条件的【请填写功能名称】列表
     *
     * @param bo 查询条件
     * @return 【请填写功能名称】列表
     */
    List<TDistrictVo> queryList(TDistrictBo bo);

    /**
     * 新增【请填写功能名称】
     *
     * @param bo 【请填写功能名称】
     * @return 是否新增成功
     */
    Boolean insertByBo(TDistrictBo bo);

    /**
     * 修改【请填写功能名称】
     *
     * @param bo 【请填写功能名称】
     * @return 是否修改成功
     */
    Boolean updateByBo(TDistrictBo bo);

    /**
     * 校验并批量删除【请填写功能名称】信息
     *
     * @param ids     待删除的主键集合
     * @param isValid 是否进行有效性校验
     * @return 是否删除成功
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    List<TDistrictVo> selectList();

    List<TDistrictVo> selectDistrictByPid(String pid);


    List<TDistrictVo> selectCityList(TDistrictVo vo);

    List<TDistrictVo> selectAreaList(TDistrictVo vo);

    /**
     * 查询地址数据
     *
     * @param vo
     * @return
     */
    List<DistrictsVo> selectDistricts(TDistrictVo vo);

    List<TDistrictVo> queryListByName(List<String> districtNames);
}